@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009,2010 Yoshikazu Kuramochi
+ * Copyright (c) 2009-2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -135,7 +135,7 @@ public class AnimatableVec3dElementDelegate extends AnimatableValueElementDelega
 
 	public boolean canEdit(int columnIndex) {
 		if (columnIndex == LayerCompositionView.VALUE_COL) {
-			return canInlineEdit;
+			return canInPlaceEdit;
 		}
 		return false;
 	}
@@ -212,7 +212,7 @@ public class AnimatableVec3dElementDelegate extends AnimatableValueElementDelega
 							if (r.contains(e.x, e.y)) {
 								valueIndex = (i < valueIndex) ? i : i+1;
 								parent.update();
-								openInlineEditor();
+								openInPlaceEditor();
 								break;
 							}
 						}
